@@ -8,46 +8,28 @@ import functools
 from pipeline import Pipeline
 
 from .helpers import format_config
+from .commands import SHARD_METHODS
 
 _findhash = re.compile('.*\{(.*)\}.*', re.I)
 
 
 class RedisShardAPI(object):
 
-    SHARD_METHODS = set([
-        "get", "set", "getset", "append", "getrange",
-        "setnx", "setex",
-        "incr", "decr", "exists",
-        "delete", "get_type", "type", "rename",
-        "expire", "ttl", "push", "persist",
-        "llen", "lrange", "ltrim", "lpush", "lpop",
-        "lindex", "pop", "lset",
-        "lrem", "sadd", "srem", "scard",
-        "sismember", "smembers",
-        "zadd", "zrem", "zincrby", "zincr", "zrank",
-        "zrange", "zrevrange", "zrangebyscore", "zremrangebyrank", "zrevrangebyscore",
-        "zremrangebyscore", "zcard", "zscore", "zcount",
-        "hget", "hset", "hdel", "hincrby", "hlen",
-        "hkeys", "hvals", "hgetall", "hexists", "hmget", "hmset",
-        "publish", "rpush", "rpop"
-    ])
+    _servers = {}
 
     def __init__(self, settings=None):
         self.nodes = []
         self.connections = {}
         settings = format_config(settings)
-        for server in settings:
-            name = server.get('name')
-            conn = redis.Redis(host=server.get('host'),
-                               port=server.get('port'),
-                               db=server.get('db'),
-                               password=server.get('password'),
-                               socket_timeout=server.get('socket_timeout'),
-                               unix_socket_path=server.get('unix_socket_path'),
-                               )
-            server['name'] = name
+        for server_config in settings:
+            name = server_config.pop('name')
+            conn = RedisShardAPI._servers.get(name, None)
+            if not conn:
+                conn = redis.Redis(**server_config)
+                RedisShardAPI._servers[name] = conn
             if name in self.connections:
                 raise ValueError("server's name config must be unique")
+            server_config['name'] = name
             self.connections[name] = conn
             self.nodes.append(name)
         self.ring = HashRing(self.nodes)
@@ -86,7 +68,7 @@ class RedisShardAPI(object):
         return f(*args, **kwargs)
 
     def __getattr__(self, method):
-        if method in self.SHARD_METHODS:
+        if method in SHARD_METHODS:
             return functools.partial(self.__wrap, method)
         elif method.startswith("tag_"):
             return functools.partial(self.__wrap_tag, method)
